Token

Struct Token 

pub struct Token {
    pub token: String,
    pub user_id: String,
    pub expiration: NaiveDateTime,
}
Token Struct

Fields

token: Stringuser_id: Stringexpiration: NaiveDateTime

Implementations

Source

impl Token

Methods related to the token struct

pub fn generate(player_id: &str) -> Result<Token, String>

Generate a new token for a player

Arguments
  • player_id - The ID of the player to generate a token for
Returns

A Result containing the generated token or an error message

fn store(&self) -> Result<String, String>

Store the token in the database

Arguments
  • self - The token to store
Returns

A Result containing the stored token or an error message

pub async fn check_token( req: &HttpRequest, user_id: &String, ) -> Result<Token, String>

Check if the token is valid and belongs to the user

Arguments
  • self - The token to check
Returns

A Result containing the token or an error message

pub fn get_token_by_player(id: &str) -> Result<Token, String>

Get a token by player ID

Arguments
  • id - The player ID to get the token for
Returns

A Result containing the token or an error message

pub fn get_token_by_token(token: &str) -> Result<Token, String>

Get a token by token ID

Arguments
  • token - The token ID to get the token for
Returns

A Result containing the token or an error message

pub fn clear_player_tokens(player: &Player) -> Result<usize, String>

Clears the tokens for a certain player

Arguments

The player who is logging out

Returns

Whether the token deletion was successful or not

pub fn clear_tokens() -> Result<usize, String>

Attempts to clear all expired tokens

Returns
  • The number of rows deleted
  • An error message